Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TopicMatch ¶
TopicMatch 返回topic和topic filter是否
TopicMatch returns whether the topic and topic filter is matched.
Types ¶
type Bus ¶
type Bus interface {
// Publish publishes arguments to the given topic subscribers
// Publish block only when the buffer of one of the subscribers is full.
Publish(topic string, args ...interface{})
// CloseTopic unsubscribe all subscribers from given topic
CloseTopic(topic string)
// Subscribe subscribes to the given topic
Subscribe(topic string, fn interface{}, options ...interface{}) error
// Unsubscribe handler from the given topic
Unsubscribe(topic string, fn interface{}) error
// Stat ...
Stat(ctx context.Context, limit, offset int64, orderBy, sort string) (stats Stats, total int64, err error)
// Purge ...
Purge()
}
Bus implements publish/subscribe messaging paradigm
type RPSCounter ¶ added in v0.16.0
type RPSCounter struct {
// contains filtered or unexported fields
}
func (*RPSCounter) Inc ¶ added in v0.16.0
func (c *RPSCounter) Inc()
func (*RPSCounter) Stop ¶ added in v0.16.0
func (c *RPSCounter) Stop()
func (*RPSCounter) Value ¶ added in v0.16.0
func (c *RPSCounter) Value() float64
type StatItem ¶ added in v0.16.0
type StatItem struct {
Topic string
Subscribers int
Min time.Duration
Max time.Duration
Avg time.Duration
Rps float64
}
StatItem ...
type Statistic ¶ added in v0.16.0
type Statistic struct {
// contains filtered or unexported fields
}
func NewStatistic ¶ added in v0.16.0
func NewStatistic() *Statistic
Click to show internal directories.
Click to hide internal directories.